DROP VIEW customer_sales_report;
DROP VIEW discount_sales;
DROP VIEW customer_sales_sum;

DROP TABLE sales_registry;
--DROP TABLE refund;
DROP TABLE sale;
DROP TABLE email;
DROP TABLE customer;
DROP TABLE magazine;


CREATE TABLE customer (
	id serial primary key,
	afm varchar unique,
	name varchar not null, check (length(name) > 2),
	born date, CHECK (born > '1900-1-1')
);

CREATE TABLE email (
 id serial primary key,
 person integer references customer(id),
 email_address varchar not null,
 description varchar,
 priority integer, 
 active boolean
);
CREATE INDEX email_email_idx ON email(email_address);



CREATE TABLE magazine (
    id serial primary key,
    name text,
    publish date unique,
    price numeric, CHECK (price > 0),
    quantity integer, CHECK (quantity >= 0)
);


CREATE TABLE sale (
id serial primary key,
order_no integer not null,
customer integer not null references customer(id),
magazine integer not null references magazine(id),
quantity integer not null, CHECK (quantity > 0),
org_price numeric not null, CHECK (org_price > 0),
sales_amount numeric not null, CHECK (sales_amount > 0),
CONSTRAINT valid_discount CHECK (sales_amount <= quantity * org_price),
sales_dt timestamp not null default now()
);

create index sale_sales_dt_idx ON sale(sales_dt);
create unique index sale_u1_idx ON sale(order_no,customer,magazine);






--CREATE TABLE refund (
--id serial primary key,
--customer integer not null references customer(id),
--money numeric not null, CHECK (money > 0),
--refund_dt timestamp default now()
--);


CREATE TABLE sales_registry (
id serial primary key,
transaction_date date,
amount numeric,
description varchar
);




CREATE VIEW discount_sales AS 
SELECT s.* FROM sale s WHERE (org_price * quantity - sales_amount) > 0;   



CREATE VIEW customer_sales_sum AS
SELECT customer , count(*) as sales_count, sum(sales_amount) as sales_sum FROM sale GROUP BY 1; 


CREATE VIEW customer_sales_report AS 
SELECT c.id, c.name , c.born, s.sales_count, s.sales_sum 
FROM customer c JOIN customer_sales_sum s
ON (c.id = s.customer);



insert into customer (id,name,afm,born) values (default,'kostas','069167973','1980-6-21');
insert into customer (id,name,afm,born) values (default,'maria' ,'032167146','1985-10-25');
insert into customer (id,name,afm,born) values (default,'nikos' ,'112863753','1994-6-15');

insert into magazine (id,name, publish, price,quantity) values (default, 'tefxos 1','2006-1-1',30.00,220);
insert into magazine (id,name, publish, price,quantity) values (default, 'tefxos 2','2006-2-1',30.00,340);
insert into magazine (id,name, publish, price,quantity) values (default, 'tefxos 3','2006-3-1',30.00,400);
insert into magazine (id,name, publish, price,quantity) values (default, 'tefxos 4','2006-4-1',30.00,500);
insert into magazine (id,name, publish, price,quantity) values (default, 'tefxos 5','2006-5-1',30.00,550);
insert into magazine (id,name, publish, price,quantity) values (default, 'tefxos 6','2006-6-1',35.50,600);


insert into sale values (default,1, 1,1,1,30.00,28.00,'2007-1-1 12:00:00');
insert into sale values (default,1, 1,2,2,30.00,56.00,'2007-1-1 12:00:00');
insert into sale values (default,1, 1,3,1,30.00,30.00,'2007-1-1 12:00:00');
insert into sale values (default,2, 2,4,1,30.00,30.00,'2007-2-1 12:00:00');
insert into sale values (default,3, 2,3,1,30.00,28.00,'2007-2-1 12:00:00');
insert into sale values (default,3, 2,4,1,30.00,30.00,'2007-2-1 12:00:00');
insert into sale values (default,4, 3,5,2,30.00,60.00,'2007-3-1 12:00:00');
insert into sale values (default,5, 3,5,1,30.00,30.00,'2007-3-1 12:00:00');
insert into sale values (default,6, 3,6,1,35.50,35.50,'2007-3-1 12:00:00');


--insert into refund values (default,1,30.00,'2007-1-2 12:00:00');






SELECT * FROM customer;	
SELECT * FROM magazine;

SELECT * FROM sale;

SELECT * FROM discount_sales;

SELECT * FROM customer_sales_sum;
SELECT * FROM customer_sales_report;



